Documentation
¶
Index ¶
- type ClusterRoleBindingLister
- type ClusterRoleBindingListerExpansion
- type ClusterRoleLister
- type ClusterRoleListerExpansion
- type RoleBindingLister
- type RoleBindingListerExpansion
- type RoleBindingNamespaceLister
- type RoleBindingNamespaceListerExpansion
- type RoleBindingRestrictionLister
- type RoleBindingRestrictionListerExpansion
- type RoleBindingRestrictionNamespaceLister
- type RoleBindingRestrictionNamespaceListerExpansion
- type RoleLister
- type RoleListerExpansion
- type RoleNamespaceLister
- type RoleNamespaceListerExpansion
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ClusterRoleBindingLister ¶
type ClusterRoleBindingLister interface {
// List lists all ClusterRoleBindings in the indexer.
List(selector labels.Selector) (ret []*authorization.ClusterRoleBinding, err error)
// Get retrieves the ClusterRoleBinding from the index for a given name.
Get(name string) (*authorization.ClusterRoleBinding, error)
ClusterRoleBindingListerExpansion
}
ClusterRoleBindingLister helps list ClusterRoleBindings.
func NewClusterRoleBindingLister ¶
func NewClusterRoleBindingLister(indexer cache.Indexer) ClusterRoleBindingLister
NewClusterRoleBindingLister returns a new ClusterRoleBindingLister.
type ClusterRoleBindingListerExpansion ¶
type ClusterRoleBindingListerExpansion interface{}
ClusterRoleBindingListerExpansion allows custom methods to be added to ClusterRoleBindingLister.
type ClusterRoleLister ¶
type ClusterRoleLister interface {
// List lists all ClusterRoles in the indexer.
List(selector labels.Selector) (ret []*authorization.ClusterRole, err error)
// Get retrieves the ClusterRole from the index for a given name.
Get(name string) (*authorization.ClusterRole, error)
ClusterRoleListerExpansion
}
ClusterRoleLister helps list ClusterRoles.
func NewClusterRoleLister ¶
func NewClusterRoleLister(indexer cache.Indexer) ClusterRoleLister
NewClusterRoleLister returns a new ClusterRoleLister.
type ClusterRoleListerExpansion ¶
type ClusterRoleListerExpansion interface{}
ClusterRoleListerExpansion allows custom methods to be added to ClusterRoleLister.
type RoleBindingLister ¶
type RoleBindingLister interface {
// List lists all RoleBindings in the indexer.
List(selector labels.Selector) (ret []*authorization.RoleBinding, err error)
// RoleBindings returns an object that can list and get RoleBindings.
RoleBindings(namespace string) RoleBindingNamespaceLister
RoleBindingListerExpansion
}
RoleBindingLister helps list RoleBindings.
func NewRoleBindingLister ¶
func NewRoleBindingLister(indexer cache.Indexer) RoleBindingLister
NewRoleBindingLister returns a new RoleBindingLister.
type RoleBindingListerExpansion ¶
type RoleBindingListerExpansion interface{}
RoleBindingListerExpansion allows custom methods to be added to RoleBindingLister.
type RoleBindingNamespaceLister ¶
type RoleBindingNamespaceLister interface {
// List lists all RoleBindings in the indexer for a given namespace.
List(selector labels.Selector) (ret []*authorization.RoleBinding, err error)
// Get retrieves the RoleBinding from the indexer for a given namespace and name.
Get(name string) (*authorization.RoleBinding, error)
RoleBindingNamespaceListerExpansion
}
RoleBindingNamespaceLister helps list and get RoleBindings.
type RoleBindingNamespaceListerExpansion ¶
type RoleBindingNamespaceListerExpansion interface{}
RoleBindingNamespaceListerExpansion allows custom methods to be added to RoleBindingNamespaceLister.
type RoleBindingRestrictionLister ¶
type RoleBindingRestrictionLister interface {
// List lists all RoleBindingRestrictions in the indexer.
List(selector labels.Selector) (ret []*authorization.RoleBindingRestriction, err error)
// RoleBindingRestrictions returns an object that can list and get RoleBindingRestrictions.
RoleBindingRestrictions(namespace string) RoleBindingRestrictionNamespaceLister
RoleBindingRestrictionListerExpansion
}
RoleBindingRestrictionLister helps list RoleBindingRestrictions.
func NewRoleBindingRestrictionLister ¶
func NewRoleBindingRestrictionLister(indexer cache.Indexer) RoleBindingRestrictionLister
NewRoleBindingRestrictionLister returns a new RoleBindingRestrictionLister.
type RoleBindingRestrictionListerExpansion ¶
type RoleBindingRestrictionListerExpansion interface{}
RoleBindingRestrictionListerExpansion allows custom methods to be added to RoleBindingRestrictionLister.
type RoleBindingRestrictionNamespaceLister ¶
type RoleBindingRestrictionNamespaceLister interface {
// List lists all RoleBindingRestrictions in the indexer for a given namespace.
List(selector labels.Selector) (ret []*authorization.RoleBindingRestriction, err error)
// Get retrieves the RoleBindingRestriction from the indexer for a given namespace and name.
Get(name string) (*authorization.RoleBindingRestriction, error)
RoleBindingRestrictionNamespaceListerExpansion
}
RoleBindingRestrictionNamespaceLister helps list and get RoleBindingRestrictions.
type RoleBindingRestrictionNamespaceListerExpansion ¶
type RoleBindingRestrictionNamespaceListerExpansion interface{}
RoleBindingRestrictionNamespaceListerExpansion allows custom methods to be added to RoleBindingRestrictionNamespaceLister.
type RoleLister ¶
type RoleLister interface {
// List lists all Roles in the indexer.
List(selector labels.Selector) (ret []*authorization.Role, err error)
// Roles returns an object that can list and get Roles.
Roles(namespace string) RoleNamespaceLister
RoleListerExpansion
}
RoleLister helps list Roles.
func NewRoleLister ¶
func NewRoleLister(indexer cache.Indexer) RoleLister
NewRoleLister returns a new RoleLister.
type RoleListerExpansion ¶
type RoleListerExpansion interface{}
RoleListerExpansion allows custom methods to be added to RoleLister.
type RoleNamespaceLister ¶
type RoleNamespaceLister interface {
// List lists all Roles in the indexer for a given namespace.
List(selector labels.Selector) (ret []*authorization.Role, err error)
// Get retrieves the Role from the indexer for a given namespace and name.
Get(name string) (*authorization.Role, error)
RoleNamespaceListerExpansion
}
RoleNamespaceLister helps list and get Roles.
type RoleNamespaceListerExpansion ¶
type RoleNamespaceListerExpansion interface{}
RoleNamespaceListerExpansion allows custom methods to be added to RoleNamespaceLister.